@@ -6,7 +6,7 @@ function fsk_lib_ldpc_tx(filename, num_frames=10, Rs=100, coderate=0.5, EbNodB=1
   fsk_lib_ldpc;
   
   % set up LDPC code
-  init_cml('~/cml/');
+  init_cml();
   if coderate == 0.5
     load H_256_512_4.mat;
   elseif coderate == 0.75
