@@ -1,36 +1,11 @@
 % tfsk.m
-% Author: Brady O'Brien 8 January 2016
-
-
-
-%   Copyright 2016 David Rowe
-%  
-%  All rights reserved.
+% Brady O'Brien 8 January 2016
+% David Rowe May 2020
 %
-%  This program is free software; you can redistribute it and/or modify
-%  it under the terms of the GNU Lesser General Public License version 2.1, as
-%  published by the Free Software Foundation.  This program is
-%  distributed in the hope that it will be useful, but WITHOUT ANY
-%  WARRANTY; without even the implied warranty of MERCHANTABILITY or
-%  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
-%  License for more details.
-%
-%  You should have received a copy of the GNU Lesser General Public License
-%  along with this program; if not, see <http://www.gnu.org/licenses/>.
-
-
-% Octave script to check c port of fsk_horus against the fsk_horus.m
-%
-% [X] - Functions to wrap around fsk_mod and fsk_demod executables
-%     [X] - fsk_mod
-%     [X] - fsk_demod
-% [X] - Functions to wrap around octave and c implementations, pass
-%       same dataset, compare outputs, and give clear go/no-go
-%     [X] - fsk_mod_test
-%     [X] - fsk_demod_test
-% [X] - Port of run_sim and EbNodB curve test battery
-% [X] - Extract and compare more parameters from demod
-% [X] - Run some tests in parallel
+% Automatic testing of C port of FSK modem by comparing to reference
+% Octave version. Currently just a subset of tests enabled in order to
+% run in a reasonable amount of time as ctests, but still trapping any
+% bit-rot.
 
 #{
 
@@ -45,32 +20,42 @@
      $ make
 
   2 - Change tfsk_location below if required
-  3 - Ensure Octave packages signal and parallel are installed
+  3 - Ensure Octave packages are installed
   4 - Start Octave and run tfsk.m. It will perform all tests automatically
 
 #}
 
-%tfsk executable path/file
-global tfsk_location = '../build_linux/unittest/tfsk';
+% tfsk executable path/file
+if getenv("PATH_TO_TFSK")
+  global tfsk_location = getenv("PATH_TO_TFSK")
+  printf("setting tfsk_location from env var: %s\n", getenv("PATH_TO_TFSK"));
+else
+  global tfsk_location = '../build_linux/unittest/tfsk';
+end
 
-%Set to 1 for verbose printouts
+% Set to 1 for verbose printouts
 global print_verbose = 0;
+global mod_pass_fail_maxdiff = 1e-3/5000;
 
-
-fsk_horus_as_a_lib = 1; % make sure calls to test functions at bottom are disabled
-%fsk_horus_2fsk;  
-fsk_horus
+fsk_horus_as_a_lib=1;
+fsk_horus;
 pkg load signal;
-pkg load parallel;
+% not needed unless parallel tests running
+%pkg load parallel;
 graphics_toolkit('gnuplot');
 
-
-global mod_pass_fail_maxdiff = 1e-3/5000;
+function print_result(test_name, result)
+  printf("%s", test_name);
+  for i=1:(40-length(test_name))
+    printf(".");
+  end
+  printf(": %s\n", result);  
+end
 
 function mod = fsk_mod_c(Fs,Rs,f1,fsp,bits,M)
     global tfsk_location;
     %command to be run by system to launch the modulator
-    command = sprintf('%s M %d %d %d %d %d fsk_mod_ut_bitvec fsk_mod_ut_modvec fsk_mod_ut_log.txt',tfsk_location,M,f1,fsp,Fs,Rs);
+    command = sprintf('%s M %d %d %d %d %d 0 fsk_mod_ut_bitvec fsk_mod_ut_modvec fsk_mod_ut_log.txt',tfsk_location,M,f1,fsp,Fs,Rs);
     %save input bits into a file
     bitvecfile = fopen('fsk_mod_ut_bitvec','wb+');
     fwrite(bitvecfile,bits,'uint8');
@@ -90,7 +75,7 @@ endfunction
 function pass = vcompare(vc,voct,vname,tname,tol,pnum)
     global print_verbose;
     %Get delta of vectors
-    dvec = abs(abs(vc)-abs(voct));     
+    dvec = abs(abs(vc - voct));     
     
     %Normalize difference
     dvec = dvec ./ abs(max(abs(voct))+1e-8);
@@ -115,7 +100,8 @@ function pass = vcompare(vc,voct,vname,tname,tol,pnum)
     
 endfunction
 
-function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
+% Run C, then Octave verion of demod, and compare results
+function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2,lock_nin=0)
     global print_verbose;
     global tfsk_location;
     %Name of executable containing the modulator
@@ -125,7 +111,7 @@ function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
     tvecfilename = sprintf('fsk_demod_ut_tracevec_%d.txt',getpid());
     
     %command to be run by system to launch the demod
-    command = sprintf('%s D %d %d %d %d %d %s %s %s',tfsk_location,M,f1,fsp,Fs,Rs,modvecfilename,bitvecfilename,tvecfilename);
+    command = sprintf('%s D %d %d %d %d %d %d %s %s %s',tfsk_location,M,f1,fsp,Fs,Rs,lock_nin,modvecfilename,bitvecfilename,tvecfilename);
     
     %save modulated input into a file
     modvecfile = fopen(modvecfilename,'wb+');
@@ -141,7 +127,7 @@ function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
     bits = bits!=0;
     
     %Load test vec dump
-    load(tvecfilename);
+    load(tvecfilename)
     
     %Clean up files
     delete(bitvecfilename);
@@ -163,32 +149,35 @@ function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
     o_EbNodB = [];
     o_ppm = [];
     o_Sf = [];
-    o_fest = [];
+    o_fest = []; o_mask = []; o_fest2 = [];
     o_rx_timing = [];
     o_norm_rx_timing = [];
     o_nin = [];
     %Run octave demod, dump some test vectors
     states = fsk_horus_init(Fs,Rs,M);
+
     Ts = states.Ts;
     P = states.P;
     states.ftx(1) = f1;
     states.ftx(2) = f1+fsp;
     states.ftx(3) = f1+fsp*2;
     states.ftx(4) = f1+fsp*3;
-    states.dA = 1;
+    states.tx_tone_separation = fsp;
     states.dF = 0;
     modin = mod;
     obits = [];
     while length(modin)>=states.nin
         ninold = states.nin;
         states = est_freq(states, modin(1:states.nin), states.M);
-        [bitbuf,states] = fsk_horus_demod(states, modin(1:states.nin));
+        [bitbuf,states] = fsk_demod(states, modin(1:states.nin));
+        if lock_nin states.nin = states.N; end
+
         modin=modin(ninold+1:length(modin));
         obits = [obits bitbuf];
         
         %Save other parameters
-        o_f1_dc = [o_f1_dc states.f_dc(1,1:states.Nmem-Ts/P)];
-        o_f2_dc = [o_f2_dc states.f_dc(2,1:states.Nmem-Ts/P)];
+        o_f1_dc = [o_f1_dc states.f_dc(1,:)];
+        o_f2_dc = [o_f2_dc states.f_dc(2,:)];
         o_f1_int = [o_f1_int states.f_int(1,:)];
         o_f2_int = [o_f2_int states.f_int(2,:)];
         o_EbNodB = [o_EbNodB states.EbNodB];
@@ -199,49 +188,46 @@ function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
         o_f1 = [o_f1 states.f(1)];
         o_f2 = [o_f1 states.f(2)];
         o_fest = [o_fest states.f];
+        o_mask = [o_mask states.mask];
+        o_fest2 = [o_fest2 states.f2];
         o_nin = [o_nin states.nin];
         if M==4
-			o_f3_dc = [o_f3_dc states.f_dc(3,1:states.Nmem-Ts/P)];
-			o_f4_dc = [o_f4_dc states.f_dc(4,1:states.Nmem-Ts/P)];
-			o_f3_int = [o_f3_int states.f_int(3,:)];
-			o_f4_int = [o_f4_int states.f_int(4,:)];
-			o_f3 = [o_f1 states.f(3)];
-			o_f4 = [o_f1 states.f(4)];
+            o_f3_dc = [o_f3_dc states.f_dc(3,:)];
+	    o_f4_dc = [o_f4_dc states.f_dc(4,:)];
+            o_f3_int = [o_f3_int states.f_int(3,:)];
+            o_f4_int = [o_f4_int states.f_int(4,:)];
+            o_f3 = [o_f1 states.f(3)];
+            o_f4 = [o_f1 states.f(4)];
         end
     end
-    
-    %close all
-    
-    % One part-per-thousand allowed on important parameters
-    pass = 1;
-    
-    pass = vcompare(o_Sf,  t_fft_est,'fft est',tname,.001,1) && pass;
-    pass = vcompare(o_fest,  t_f_est,'f est',tname,.001,2) && pass;
-    pass = vcompare(o_rx_timing,  t_rx_timing,'rx timing',tname,.02,3) && pass;
-    
+        
+    assert(vcompare(o_Sf,  t_Sf,'fft est',tname,.001,1));
+    assert(vcompare(o_fest,  t_f_est,'f est',tname,.001,2));
+    assert(vcompare(o_mask,  t_mask,'f2 mask',tname,.001,3));
+    assert(vcompare(o_fest2,  t_f2_est,'f2 est',tname,.001,16));
+    o_fest2(1:12)
+    t_f2_est(1:12)
+    assert(vcompare(o_f1_dc,      t_f1_dc,    'f1 dc',    tname,.01,8));
+    assert(vcompare(o_f2_dc,      t_f2_dc,    'f2 dc',    tname,.01,9));
+    assert(vcompare(o_f2_int,     t_f2_int,   'f2 int',   tname,.01,10));
+    assert(vcompare(o_f1_int,     t_f1_int,   'f1 int',   tname,.01,11));
     if M==4
-        pass = vcompare(o_f3_dc,      t_f3_dc,    'f3 dc',    tname,.005,4) && pass;
-        pass = vcompare(o_f4_dc,      t_f4_dc,    'f4 dc',    tname,.005,5) && pass;
-        pass = vcompare(o_f3_int,     t_f3_int,   'f3 int',   tname,.005,6) && pass;
-        pass = vcompare(o_f4_int,     t_f4_int,   'f4 int',   tname,.005,7) && pass;
+        assert(vcompare(o_f3_dc,      t_f3_dc,    'f3 dc',    tname,.01,4))
+        assert(vcompare(o_f4_dc,      t_f4_dc,    'f4 dc',    tname,.01,5));
+        assert(vcompare(o_f3_int,     t_f3_int,   'f3 int',   tname,.01,6));
+        assert(vcompare(o_f4_int,     t_f4_int,   'f4 int',   tname,.01,7));
     end
-    
-    pass = vcompare(o_f1_dc,      t_f1_dc,    'f1 dc',    tname,.005,8) && pass;
-    pass = vcompare(o_f2_dc,      t_f2_dc,    'f2 dc',    tname,.005,9) && pass;
-    pass = vcompare(o_f2_int,     t_f2_int,   'f2 int',   tname,.005,10) && pass;
-    pass = vcompare(o_f1_int,     t_f1_int,   'f1 int',   tname,.005,11) && pass;
-
+  
+    assert(vcompare(o_rx_timing,  t_rx_timing,'rx timing',tname,.02,3));
+ 
     % Much larger tolerances on unimportant statistics
-    pass = vcompare(o_ppm   ,     t_ppm,      'ppm',      tname,.02,12) && pass;
-    pass = vcompare(o_EbNodB,     t_EbNodB,'EbNodB',      tname,.02,13) && pass;
-    pass = vcompare(o_nin,        t_nin,      'nin',      tname,.0001,14) && pass;
-    pass = vcompare(o_norm_rx_timing,  t_norm_rx_timing,'norm rx timing',tname,.02,15) && pass;
-    
-    assert(pass);
+    assert(vcompare(o_ppm   ,     t_ppm,      'ppm',      tname,.02,12));
+    assert(vcompare(o_EbNodB,     t_EbNodB,'EbNodB',      tname,.02,13));
+    assert(vcompare(o_nin,        t_nin,      'nin',      tname,.0001,14));
+    assert(vcompare(o_norm_rx_timing,  t_norm_rx_timing,'norm rx timing',tname,.02,15));
     diffpass = sum(xor(obits,bits'))<4;
     diffbits = sum(xor(obits,bits'));
-    
-    
+        
     if diffpass==0
         printf('\n***bitcompare test failed test %s diff %d\n\n',tname,sum(xor(obits,bits')))
         figure(15)
@@ -249,16 +235,15 @@ function test_stats = fsk_demod_xt(Fs,Rs,f1,fsp,mod,tname,M=2)
         title(sprintf('Bitcompare failure test %s',tname))
     end
     
-    pass = pass && diffpass;
+    assert(diffpass);    
     
-    
-    test_stats.pass = pass;
+    test_stats.pass = 1;
     test_stats.diff = sum(xor(obits,bits'));
     test_stats.cbits = bits';
     test_stats.obits = obits;
-    
 endfunction
 
+
 function [dmod,cmod,omod,pass] = fsk_mod_test(Fs,Rs,f1,fsp,bits,tname,M=2)
     global mod_pass_fail_maxdiff;
     %Run the C modulator
@@ -271,14 +256,13 @@ function [dmod,cmod,omod,pass] = fsk_mod_test(Fs,Rs,f1,fsp,bits,tname,M=2)
     states.ftx(2) = f1+fsp;
     
     if states.M == 4
-		states.ftx(3) = f1+fsp*2;
-		states.ftx(4) = f1+fsp*3;
+        states.ftx(3) = f1+fsp*2;
+        states.ftx(4) = f1+fsp*3;
     end
     
-    states.dA = [1 1 1 1]; 
     states.dF = 0;
-    omod = fsk_horus_mod(states,bits);
-    
+    omod = fsk_mod(states,bits);
+
     dmod = cmod-omod;
     pass = max(dmod)<(mod_pass_fail_maxdiff*length(dmod));
     if !pass
@@ -299,7 +283,7 @@ function pass = test_mod_horuscfg_randbits
         plot(dmod)
         title("Difference between octave and C mod impl");
     end
-    
+    print_result("test_mod_horuscfg_randbits", "OK");
 endfunction
 
 % Random bit modulator test
@@ -315,23 +299,24 @@ function pass = test_mod_horuscfgm4_randbits
         plot(dmod)
         title("Difference between octave and C mod impl");
     end
+    print_result("test_mod_horuscfgm4_randbits", "OK");
     
 endfunction
 
-% A big ol' channel impairment tester
-% Shamlessly taken from fsk_horus
-% This throws some channel imparment or another at the C and octave modem so they 
-% may be compared.
-function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,M=2)
-  global print_verbose;
-  frames = 90;
-  %EbNodB = 10;
-  %timing_offset = 2.0; % see resample() for clock offset below
-  %fading = 0;          % modulates tx power at 2Hz with 20dB fade depth, 
-                       % to simulate balloon rotating at end of mission
-  %df     = 0;          % tx tone freq drift in Hz/s
-  %dA     = 1;          % amplitude imbalance of tones (note this affects Eb so not a gd idea)
 
+% A big ol' channel impairment tester shamelessly taken from fsk_horus
+% This throws some channel imparment or another at the C and octave
+% modem so they may be compared.
+function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,M=2,frames=50,lock_nin=0)
+  #{  
+  timing_offset [0|1]  enable a 1000ppm sample clock offset
+  fading        [0|1]  modulates tx power at 2Hz with 20dB fade depth, 
+                       e.g. to simulate balloon rotating at end of mission
+  df                   tx tone freq drift in Hz/s
+  lock_nin      [0|1]  locks nin to a constant which makes tests much simpler by breaking feeback loop
+  #}
+  global print_verbose;
+  
   more off
   rand('state',1); 
   randn('state',1);
@@ -348,7 +333,6 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
     states = fsk_horus_init(8000, 100, M);
     states.f1_tx = 1200;
     states.f2_tx = 1600;
-    
   end
 
   if test_frame_mode == 4
@@ -371,14 +355,13 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
 
   % ----------------------------------------------------------------------
 
-  states.verbose = 0;%x1;
+  states.verbose = 0;
   N = states.N;
   P = states.P;
   Rs = states.Rs;
   nsym = states.nsym;
   Fs = states.Fs;
   states.df = df;
-  states.dA = [dA dA dA dA];
   states.M = M;
 
   EbNo = 10^(EbNodB/10);
@@ -419,7 +402,6 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
   
   f1 = states.f1_tx;
   fsp = states.f2_tx-f1;
-  states.dA = [dA dA dA dA];
   states.ftx(1) = f1;
   states.ftx(2) = f1+fsp;
     
@@ -428,7 +410,7 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
 	states.ftx(4) = f1+fsp*3;
   end
 
-  tx = fsk_horus_mod(states, tx_bits);
+  tx = fsk_mod(states, tx_bits);
 
   if timing_offset
     tx = resample(tx, 1000, 1001); % simulated 1000ppm sample clock offset
@@ -443,7 +425,7 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
   rx    = tx + noise;
   
   test_name = sprintf("tfsk run sim EbNodB:%d frames:%d timing_offset:%d fading:%d df:%d",EbNodB,frames,timing_offset,fading,df);
-  tstats = fsk_demod_xt(Fs,Rs,states.f1_tx,fsp,rx,test_name,M);
+  tstats = fsk_demod_xt(Fs,Rs,states.f1_tx,fsp,rx,test_name,M,lock_nin);
   
   pass = tstats.pass;
   obits = tstats.obits;
@@ -506,8 +488,8 @@ function stats = tfsk_run_sim(test_frame_mode,EbNodB,timing_offset,fading,df,dA,
   stats.pass = pass;
 endfunction
 
-
-function pass = ebno_battery_test(timing_offset,fading,df,dA,M)
+% run a bunch of tests at a range of EbNo's in parallel
+function pass = ebno_battery_test(timing_offset,fading,df,M)
     %Range of EbNodB over which to test
     ebnodbrange = (5:2:13);
     ebnodbs = length(ebnodbrange);
@@ -518,11 +500,9 @@ function pass = ebno_battery_test(timing_offset,fading,df,dA,M)
     timingv = repmat(timing_offset,1,ebnodbs);
     fadingv = repmat(fading,1,ebnodbs);
     dfv     = repmat(df,1,ebnodbs);
-    dav     = repmat(dA,1,ebnodbs);
     mv      = repmat(M,1,ebnodbs);
-    statv = pararrayfun(floor(1.25*nproc()),@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,dav,mv);
-    %statv = arrayfun(@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,dav,mv);
 
+    statv = pararrayfun(floor(1.25*nproc()),@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,mv);
     passv = zeros(1,length(statv));
     for ii=(1:length(statv))
         passv(ii)=statv(ii).pass;
@@ -542,26 +522,23 @@ function pass = ebno_battery_test(timing_offset,fading,df,dA,M)
 endfunction
 
 %Test with and without sample clock offset
-function pass = test_timing_var(df,dA,M)
-    pass = ebno_battery_test(1,0,df,dA,M)
+function pass = test_timing_var(df,M)
+    pass = ebno_battery_test(1,0,df,M)
     assert(pass)
-    pass = pass && ebno_battery_test(0,0,df,dA,M)
+    pass = pass && ebno_battery_test(0,0,df,M)
     assert(pass)
 endfunction
 
 %Test with and without 1 Hz/S freq drift
 function pass = test_drift_var(M)
     pass = test_timing_var(1,1,M)
-    assert(pass)
     pass = pass && test_timing_var(0,1,M)
     assert(pass)
 endfunction
 
 function pass = test_fsk_battery()
     pass = test_mod_horuscfg_randbits;
-    assert(pass)
     pass = pass && test_mod_horuscfgm4_randbits;
-    assert(pass)
     pass = pass && test_drift_var(4);
     assert(pass)
     pass = pass && test_drift_var(2);
@@ -586,12 +563,10 @@ function plot_fsk_bers(M=2)
     timingv = repmat(1,1,ebnodbs);
     fadingv = repmat(0,1,ebnodbs);
     dfv     = repmat(1,1,ebnodbs);
-    dav     = repmat(1,1,ebnodbs);
     Mv     = repmat(M,1,ebnodbs);
-    
-    
-    statv = pararrayfun(floor(nproc()),@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,dav,Mv);
-    %statv = arrayfun(@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,dav,Mv);
+        
+    statv = pararrayfun(floor(nproc()),@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,Mv);
+    %statv = arrayfun(@tfsk_run_sim,modev,ebnodbrange,timingv,fadingv,dfv,Mv);
     
     for ii = (1:length(statv))
         stat = statv(ii);
@@ -617,14 +592,20 @@ function plot_fsk_bers(M=2)
  
 endfunction
 
-
-xpass = test_fsk_battery
-%plot_fsk_bers(2)
-plot_fsk_bers(4)
-
-if xpass
-    printf("***** All tests passed! *****\n");
-else
-    printf("***** Some test failed! Look back thorugh output to find failed test *****\n");
+% We kick off tests here ------------------------------------------------------
+   
+pass = 0; ntests = 0;
+pass += test_mod_horuscfg_randbits; ntests++;
+pass += test_mod_horuscfgm4_randbits; ntests++;
+stats = tfsk_run_sim(test_frame_mode=2,EbNodB=5,timing_offset=0,fading=0,df=1,M=4,frames=10,lock_nin=1); ntests++;
+if stats.pass
+  print_result("Demod 10 frames nin locked", "OK");
+  pass += stats.pass; 
 end
-
+stats = tfsk_run_sim(test_frame_mode=2,EbNodB=5,timing_offset=1,fading=0,df=1,M=4,frames=10,lock_nin=0); ntests++;
+if stats.pass
+  print_result("Demod 10 frames", "OK");
+  pass += stats.pass;
+end
+printf("tests: %d passed: %d ", ntests, pass);
+if ntests == pass printf("PASS\n"); else printf("FAIL\n"); end
