@@ -20,10 +20,10 @@
   Multiple filters can use these coefficients because they are read-only.
 
   Although a sample rate is specified, the filters may be used at other sample rates. For example, if
-  filtP750S1040 is used at 48000 sps, the pass and stop frequencies are 4500 and 6240 hz.
+  filtP750S1040 is used at 48000 sps, the pass and stop frequencies are 4500 and 6240 Hz.
 */
 
-// Low pass filter, sample rate 8000 hz, 0.2 dB ripple, 100 dB atten, pass 550 hz, stop 750 hz.
+// Low pass filter, sample rate 8000 hz, 0.2 dB ripple, 100 dB atten, pass 550 Hz, stop 750 Hz.
 // Used to build 700D BPF
 float filtP550S750[160]={
  0.000001500540125945, 0.000020553368071006, 0.000052842049763802, 0.000112071233638701,
@@ -400,6 +400,119 @@ float filtP900S1100[]={
    0.0004418158615696
 };
 
+/*
+  Low pass filter, sample rate 8000 Hz, 60dB dB atten, pass 1100 Hz, stop 1300 Hz
+  Designed for 2020B.
+
+  Generated using Octave:
+  octave:77> h = fir1(99, 2400/8000); f=500:1500; w=f*pi/4000; H=freqz(h,1,w); 
+  octave:78> clf; plot(f,20*log10(abs(H))); grid; axis([500 1500 -60 10])
+  octave:79> save_array_c_header(h,"filtP1100S1300","t.h")
+*/
+
+float filtP1100S1300[]={
+   0.0002976192596492,
+   0.0005268501327879,
+   0.0003323197705342,
+  -0.0001770640927819,
+  -0.0006221531076115,
+  -0.0006005231876771,
+  -0.0000195189229256,
+   0.0007355731515642,
+   0.0010099584762544,
+   0.0004067132502827,
+  -0.0007585687884437,
+  -0.0015415736366462,
+  -0.0010864635373405,
+   0.0005254729116986,
+   0.0020855203587287,
+   0.0021026629812395,
+   0.0001529382567188,
+  -0.0024362700654142,
+  -0.0033992733694222,
+  -0.0014410368832294,
+   0.0023100278520809,
+   0.0047915084415380,
+   0.0034240108979541,
+  -0.0013824387082528,
+  -0.0059564413269030,
+  -0.0060581288076594,
+  -0.0006611518028655,
+   0.0064434052119832,
+   0.0091346892160535,
+   0.0040759939927406,
+  -0.0056953567245917,
+  -0.0122613043769937,
+  -0.0090272691278832,
+   0.0030572766146697,
+   0.0148523753937746,
+   0.0156061208345573,
+   0.0022854541227764,
+  -0.0160929898905979,
+  -0.0239498761167209,
+  -0.0116013322861975,
+   0.0147513846300672,
+   0.0346571639712145,
+   0.0277787088019838,
+  -0.0082808984532188,
+  -0.0505010122605824,
+  -0.0613407201912362,
+  -0.0130972319259225,
+   0.0900965824440442,
+   0.2087764094817421,
+   0.2877718571344791,
+   0.2877718571344791,
+   0.2087764094817421,
+   0.0900965824440442,
+  -0.0130972319259225,
+  -0.0613407201912362,
+  -0.0505010122605824,
+  -0.0082808984532188,
+   0.0277787088019838,
+   0.0346571639712145,
+   0.0147513846300672,
+  -0.0116013322861975,
+  -0.0239498761167209,
+  -0.0160929898905979,
+   0.0022854541227764,
+   0.0156061208345573,
+   0.0148523753937746,
+   0.0030572766146697,
+  -0.0090272691278832,
+  -0.0122613043769937,
+  -0.0056953567245917,
+   0.0040759939927406,
+   0.0091346892160535,
+   0.0064434052119832,
+  -0.0006611518028655,
+  -0.0060581288076594,
+  -0.0059564413269030,
+  -0.0013824387082528,
+   0.0034240108979541,
+   0.0047915084415380,
+   0.0023100278520809,
+  -0.0014410368832294,
+  -0.0033992733694222,
+  -0.0024362700654142,
+   0.0001529382567188,
+   0.0021026629812395,
+   0.0020855203587287,
+   0.0005254729116986,
+  -0.0010864635373405,
+  -0.0015415736366462,
+  -0.0007585687884437,
+   0.0004067132502827,
+   0.0010099584762544,
+   0.0007355731515642,
+  -0.0000195189229256,
+  -0.0006005231876771,
+  -0.0006221531076115,
+  -0.0001770640927819,
+   0.0003323197705342,
+   0.0005268501327879,
+   0.0002976192596492
+};
+
 // FIR filter suitable for changing rates 7500 to/from 8000
 // Sample 120000 Hz, pass 2700, stop 3730, ripple 0.1dB, atten 100 dB.  Stop 0.03108.
 float quiskFilt120t480[480] = {
@@ -500,3 +613,4 @@ float quiskFilt120t480[480] = {
  0.000023463361155584, 0.000017966192635412, 0.000013350669444763, 0.000009551098482930, 0.000006499942123311,
  0.000004115682735322, 0.000002322193058869, 0.000001038946634000, 0.000000197734700398, -0.000000267011791999,
 -0.000005050567303837 };
+
