@@ -4,12 +4,13 @@
   AUTHOR......: David Rowe
   DATE CREATED: August 2014
 
-  Library of API functions that implement FreeDV "modes", useful for
+  Library of API functions that implement the FreeDV API, useful for
   embedding FreeDV in other programs.  Please see:
 
   1. README_freedv.md
   2. Notes on function use in freedv_api.c
-  3. The sample freedv_tx.c and freedv_rx.c programs
+  3. Simple demo programs in the "demo" directory
+  4. The full featured command line freedv_tx.c and freedv_rx.c programs
 
 \*---------------------------------------------------------------------------*/
 
@@ -49,6 +50,7 @@
 #define FREEDV_MODE_700C        6
 #define FREEDV_MODE_700D        7
 #define FREEDV_MODE_2020        8
+#define FREEDV_MODE_2020B      16
 #define FREEDV_MODE_700E       13
 
 // available data modes
@@ -112,6 +114,9 @@
 #if !defined(FREEDV_MODE_2020_EN)
         #define FREEDV_MODE_2020_EN FREEDV_MODE_EN_DEFAULT
 #endif
+#if !defined(FREEDV_MODE_2020B_EN)
+        #define FREEDV_MODE_2020B_EN FREEDV_MODE_EN_DEFAULT
+#endif
 #if !defined(FREEDV_MODE_FSK_LDPC_EN)
         #define FREEDV_MODE_FSK_LDPC_EN FREEDV_MODE_EN_DEFAULT
 #endif
@@ -132,7 +137,7 @@ struct freedv;
 
 // Some modes allow extra configuration parameters
 struct freedv_advanced {
-    int interleave_frames;                   // currently ignored, was previously used to configure 700D interleaver
+    int interleave_frames;                   // now unused but remains to prevent breaking API for legacy apps
 
     // parameters for FREEDV_MODE_FSK_LDPC
     int M;                                   // 2 or 4 FSK
@@ -145,7 +150,6 @@ struct freedv_advanced {
 
 // Called when text message char is decoded
 typedef void (*freedv_callback_rx)(void *, char);
-typedef void (*freedv_callback_rx_sym)(void *, _Complex float, float);
 // Called when new text message char is needed
 typedef char (*freedv_callback_tx)(void *);
 typedef void (*freedv_calback_error_pattern)
@@ -212,7 +216,6 @@ int freedv_check_crc16_unpacked(unsigned char *unpacked_bits, int nbits);
 // Set parameters ------------------------------------------------------------
 
 void freedv_set_callback_txt            (struct freedv *freedv, freedv_callback_rx rx, freedv_callback_tx tx, void *callback_state);
-void freedv_set_callback_txt_sym        (struct freedv *freedv, freedv_callback_rx_sym rx, void *callback_state);
 void freedv_set_callback_protocol       (struct freedv *freedv, freedv_callback_protorx rx, freedv_callback_prototx tx, void *callback_state);
 void freedv_set_callback_data           (struct freedv *freedv, freedv_callback_datarx datarx, freedv_callback_datatx datatx, void *callback_state);
 void freedv_set_test_frames		        (struct freedv *freedv, int test_frames);
@@ -241,6 +244,7 @@ void freedv_set_phase_est_bandwidth_mode(struct freedv *f, int val);
 void freedv_set_eq                      (struct freedv *f, int val);
 void freedv_set_frames_per_burst        (struct freedv *f, int framesperburst);
 void freedv_passthrough_gain            (struct freedv *f, float g);
+int freedv_set_tuning_range             (struct freedv *freedv, float val_fmin, float val_fmax);
 
 // Get parameters -------------------------------------------------------------------------
 
