@@ -35,10 +35,6 @@
 /* This needs square roots, may take more cpu time than it's worth */
 #define EST_EBNO
 
-/* This is a flag to make the mod/demod allocate their memory on the stack instead of the heap */
-/* At large sample rates, there's not enough stack space to run the demod */
-#define DEMOD_ALLOC_STACK
-
 /* This is a flag for the freq. estimator to use a precomputed/rt computed hann window table
    On platforms with slow cosf, this will produce a substantial speedup at the cost of a small
     amount of memory 
@@ -472,14 +468,8 @@ void fsk_demod_freq_est(struct FSK *fsk, COMP fsk_in[], float *freqs, int M) {
     int freqi[M];
     int st,en,f_zero;
     
-    /* Array to do complex FFT from using kiss_fft */
-    #ifdef DEMOD_ALLOC_STACK
-    kiss_fft_cpx *fftin  = (kiss_fft_cpx*)alloca(sizeof(kiss_fft_cpx)*Ndft);
-    kiss_fft_cpx *fftout = (kiss_fft_cpx*)alloca(sizeof(kiss_fft_cpx)*Ndft);
-    #else
     kiss_fft_cpx *fftin  = (kiss_fft_cpx*)malloc(sizeof(kiss_fft_cpx)*Ndft);
     kiss_fft_cpx *fftout = (kiss_fft_cpx*)malloc(sizeof(kiss_fft_cpx)*Ndft);
-    #endif
     
     st = (fsk->est_min*Ndft)/Fs + Ndft/2; if (st < 0) st = 0;
     en = (fsk->est_max*Ndft)/Fs + Ndft/2; if (en > Ndft) en = Ndft;
@@ -605,14 +595,13 @@ void fsk_demod_freq_est(struct FSK *fsk, COMP fsk_in[], float *freqs, int M) {
     //fprintf(stderr, "fsk->tone_spacing: %d\n",fsk->tone_spacing);
     for (int m=0; m<M; m++)
         fsk->f2_est[m] = foff + m*fsk->tone_spacing;
+
     #ifdef MODEMPROBE_ENABLE
     modem_probe_samp_f("t_f2_est",fsk->f2_est,M);
     #endif
 
-    #ifndef DEMOD_ALLOC_STACK
     free(fftin);
     free(fftout);
-    #endif
 }
 
 /* core demodulator function */
@@ -878,7 +867,7 @@ void fsk_demod_core(struct FSK *fsk, uint8_t rx_bits[], float rx_filt[], COMP fs
     /* due to oversample rate P, we have too many samples for eye
        trace.  So lets output a decimated version.  We use 2P
        as we want two symbols worth of samples in trace  */
-
+#ifndef __EMBEDDED__
     int neyesamp_dec = ceil(((float)P*2)/MODEM_STATS_EYE_IND_MAX);
     neyesamp = (P*2)/neyesamp_dec;
     assert(neyesamp <= MODEM_STATS_EYE_IND_MAX);
@@ -926,7 +915,8 @@ void fsk_demod_core(struct FSK *fsk, uint8_t rx_bits[], float rx_filt[], COMP fs
 
     for(i=0; i<M; i++)
         fsk->stats->f_est[i] = f_est[i];
-    
+#endif // !__EMBEDDED__
+ 
     /* Dump some internal samples */
     modem_probe_samp_f("t_EbNodB",&(fsk->EbNodB),1);
     modem_probe_samp_f("t_ppm",&(fsk->ppm),1);
@@ -967,7 +957,7 @@ static void stats_init(struct FSK *fsk) {
     /* asserts below as we found some problems over-running eye matrix */
     
     /* TODO: refactor eye tracing code here and in fsk_demod */
-    
+#ifndef __EMBEDDED__    
     int neyesamp_dec = ceil(((float)P*2)/MODEM_STATS_EYE_IND_MAX);
     int neyesamp = (P*2)/neyesamp_dec;
     assert(neyesamp <= MODEM_STATS_EYE_IND_MAX);
@@ -984,6 +974,7 @@ static void stats_init(struct FSK *fsk) {
            }
         }
     }
+#endif // !__EMBEDDED__
 
     fsk->stats->rx_timing = fsk->stats->snr_est = 0;
     
@@ -1017,12 +1008,13 @@ void fsk_get_demod_stats(struct FSK *fsk, struct MODEM_STATS *stats){
     stats->snr_est = fsk->stats->snr_est;           // TODO: make this SNR not Eb/No
     stats->rx_timing = fsk->stats->rx_timing;
     stats->foff = fsk->stats->foff;
-
+#ifndef __EMBEDDED__
     stats->neyesamp = fsk->stats->neyesamp;
     stats->neyetr = fsk->stats->neyetr;
     memcpy(stats->rx_eye, fsk->stats->rx_eye, sizeof(stats->rx_eye));
     memcpy(stats->f_est, fsk->stats->f_est, fsk->mode*sizeof(float));
-        
+#endif // !__EMBEDDED__
+ 
     /* these fields not used for FSK so set to something sensible */
 
     stats->sync = 0;
