@@ -79,7 +79,7 @@ void encode(struct LDPC *ldpc, unsigned char ibits[], unsigned char pbits[]) {
 
         for (i=0; i<ldpc->max_row_weight; i++) {
             ind = H_rows[p + i*ldpc->NumberParityBits];
-            par = par + ibits[ind-1];
+            if (ind) par = par + ibits[ind-1];
         }
 
         tmp = par + prev;
@@ -545,8 +545,8 @@ int run_ldpc_decoder(struct LDPC *ldpc, uint8_t out_char[], float input[], int *
     for(i=0; i<CodeLength; i++) DecodedBits[i] = 0;
 
     /* Call function to do the actual decoding */
-    int iter = SumProduct( parityCheckCount, DecodedBits, c_nodes, v_nodes, 
-                           CodeLength, NumberParityBits, max_iter, 
+    int iter = SumProduct( parityCheckCount, DecodedBits, c_nodes, v_nodes,
+                           CodeLength, NumberParityBits, max_iter,
                            r_scale_factor, q_scale_factor, data_int );
 
     for (i=0; i<CodeLength; i++) out_char[i] = DecodedBits[i];
@@ -566,7 +566,7 @@ int run_ldpc_decoder(struct LDPC *ldpc, uint8_t out_char[], float input[], int *
 }
 
 
-void sd_to_llr(float llr[], double sd[], int n) {
+void sd_to_llr(float llr[], float sd[], int n) {
     double sum, mean, sign, sumsq, estvar, estEsN0, x;
     int i;
 
@@ -582,7 +582,7 @@ void sd_to_llr(float llr[], double sd[], int n) {
     sum = sumsq = 0.0;
     for(i=0; i<n; i++) {
         sign = (sd[i] > 0.0L) - (sd[i] < 0.0L);
-        x = (sd[i]/mean - sign);
+        x = ((double)sd[i]/mean - sign);
         sum += x;
         sumsq += x*x;
     }
@@ -637,9 +637,10 @@ void Demod2D(float   symbol_likelihood[],       /* output, M*number_symbols
 
 void Somap(float  bit_likelihood[],      /* number_bits, bps*number_symbols */
            float  symbol_likelihood[],   /* M*number_symbols                */
-           int     number_symbols)
+           int    M,                     /* constellation size              */
+           int    bps,                   /* bits per symbol                 */
+           int    number_symbols)
 {
-    int    M=QPSK_CONSTELLATION_SIZE, bps = QPSK_BITS_PER_SYMBOL;
     int    n,i,j,k,mask;
     float num[bps], den[bps];
     float metric;
@@ -685,25 +686,104 @@ void symbols_to_llrs(float llr[], COMP rx_qpsk_symbols[], float rx_amps[], float
     float bit_likelihood[nsyms*QPSK_BITS_PER_SYMBOL];
 
     Demod2D(symbol_likelihood, rx_qpsk_symbols, S_matrix, EsNo, rx_amps, mean_amp, nsyms);
-    Somap(bit_likelihood, symbol_likelihood, nsyms);
+    Somap(bit_likelihood, symbol_likelihood, QPSK_CONSTELLATION_SIZE, QPSK_BITS_PER_SYMBOL, nsyms);
     for(i=0; i<nsyms*QPSK_BITS_PER_SYMBOL; i++) {
         llr[i] = -bit_likelihood[i];
     }
 }
 
-void ldpc_print_info(struct LDPC *ldpc) {
-fprintf(stderr, "ldpc->max_iter = %d\n", ldpc->max_iter);
-fprintf(stderr, "ldpc->dec_type = %d\n", ldpc->dec_type);
-fprintf(stderr, "ldpc->q_scale_factor = %d\n", ldpc->q_scale_factor);
-fprintf(stderr, "ldpc->r_scale_factor = %d\n", ldpc->r_scale_factor);
-fprintf(stderr, "ldpc->CodeLength = %d\n", ldpc->CodeLength);
-fprintf(stderr, "ldpc->NumberParityBits = %d\n", ldpc->NumberParityBits);
-fprintf(stderr, "ldpc->NumberRowsHcols = %d\n", ldpc->NumberRowsHcols);
-fprintf(stderr, "ldpc->max_row_weight = %d\n", ldpc->max_row_weight);
-fprintf(stderr, "ldpc->max_col_weight = %d\n", ldpc->max_col_weight);
-fprintf(stderr, "ldpc->data_bits_per_frame = %d\n", ldpc->data_bits_per_frame);
-fprintf(stderr, "ldpc->coded_bits_per_frame = %d\n", ldpc->coded_bits_per_frame);
-fprintf(stderr, "ldpc->coded_syms_per_frame = %d\n", ldpc->coded_syms_per_frame);
+/*
+   Description: Transforms M-dimensional FSK symbols into ML symbol log-likelihoods
+
+   The calling syntax is:
+      [output] = FskDemod( input, EsNo, [csi_flag], [fade_coef] )
+
+   Where:
+      output    = M by N matrix of symbol log-likelihoods
+
+      input     = M by N matrix of (complex) matched filter outputs
+	  EsNo      = the symbol SNR (in linear, not dB, units)
+	  csi_flag  = 0 for coherent reception (default)
+	              1 for noncoherent reception w/ perfect amplitude estimates
+		      2 for noncoherent reception without amplitude estimates
+	  fade_coef = 1 by N matrix of (complex) fading coefficients (defaults to all-ones, i.e. AWGN)
+
+   Copyright (C) 2006, Matthew C. Valenti
+
+   Last updated on May 6, 2006
+
+   Function DemodFSK is part of the Iterative Solutions
+   Coded Modulation Library. The Iterative Solutions Coded Modulation
+   Library is free software; you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation; either version 2.1 of the License,
+   or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+*/
+
+/* the logI_0 function */
+static float logbesseli0(float x)
+{
+    if (x < 1)
+        return( 0.226*x*x+0.0125*x-0.0012 );
+    else if (x < 2)
+        return( 0.1245*x*x+0.2177*x-0.108 );
+    else if (x < 5)
+        return( 0.0288*x*x+0.6314*x-0.5645 );
+    else if (x < 20)
+        return( 0.002*x*x+0.9048*x-1.2997 );
+    else
+        return(0.9867*x-2.2053);
 }
 
-/* vi:set ts=4 et sts=4: */
+/* Function that does the demodulation (can be used in stand-alone C) */
+
+static void FskDemod(float out[], float yr[], float v_est, float SNR, int M, int number_symbols)
+{
+    int i, j;
+    float y_envelope, scale_factor;
+
+    scale_factor = 2*SNR;
+    for (i=0;i<number_symbols;i++) {
+        for (j=0;j<M;j++) {
+            y_envelope = sqrt( yr[j*number_symbols+i]*yr[j*number_symbols+i]/(v_est*v_est));
+            out[i*M+j] = logbesseli0( scale_factor*y_envelope );
+        }
+    }
+}
+
+void fsk_rx_filt_to_llrs(float llr[], float rx_filt[], float v_est, float SNRest, int M, int nsyms) {
+    int i;
+    int bps = log2(M);
+    float symbol_likelihood[M*nsyms];
+    float bit_likelihood[bps*nsyms];
+
+    FskDemod(symbol_likelihood, rx_filt, v_est, SNRest, M, nsyms);
+    Somap(bit_likelihood, symbol_likelihood, M, bps, nsyms);
+    for(i=0; i<bps*nsyms; i++) {
+        llr[i] = -bit_likelihood[i];
+    }
+}
+
+void ldpc_print_info(struct LDPC *ldpc) {
+    fprintf(stderr, "ldpc->max_iter = %d\n", ldpc->max_iter);
+    fprintf(stderr, "ldpc->dec_type = %d\n", ldpc->dec_type);
+    fprintf(stderr, "ldpc->q_scale_factor = %d\n", ldpc->q_scale_factor);
+    fprintf(stderr, "ldpc->r_scale_factor = %d\n", ldpc->r_scale_factor);
+    fprintf(stderr, "ldpc->CodeLength = %d\n", ldpc->CodeLength);
+    fprintf(stderr, "ldpc->NumberParityBits = %d\n", ldpc->NumberParityBits);
+    fprintf(stderr, "ldpc->NumberRowsHcols = %d\n", ldpc->NumberRowsHcols);
+    fprintf(stderr, "ldpc->max_row_weight = %d\n", ldpc->max_row_weight);
+    fprintf(stderr, "ldpc->max_col_weight = %d\n", ldpc->max_col_weight);
+    fprintf(stderr, "ldpc->data_bits_per_frame = %d\n", ldpc->data_bits_per_frame);
+    fprintf(stderr, "ldpc->coded_bits_per_frame = %d\n", ldpc->coded_bits_per_frame);
+}
