@@ -45,7 +45,7 @@
 
 #ifdef __EMBEDDED__
 #include "arm_math.h"
-#endif /* __EMBEDDED_ */
+#endif /* __EMBEDDED__ */
 
 /* Static Prototypes */
 
@@ -219,6 +219,8 @@ struct OFDM *ofdm_create(const struct OFDM_CONFIG *config) {
         ofdm->clip_en = false;
         ofdm->foff_limiter = false;
         ofdm->data_mode = "";
+        ofdm->fmin = -50.0;                       /* frequency minimum for ofdm acquisition range */
+        ofdm->fmax = 50.0;                        /* frequency maximum for ofdm acquisition range */
         memset(ofdm->tx_uw, 0, ofdm->nuwbits);
     } else {
         /* Use the users values */
@@ -252,6 +254,8 @@ struct OFDM *ofdm_create(const struct OFDM_CONFIG *config) {
         ofdm->clip_en = config->clip_en;
         memcpy(ofdm->tx_uw, config->tx_uw, ofdm->nuwbits);
         ofdm->data_mode = config->data_mode;
+        ofdm->fmin = config->fmin;              /* frequency minimum for ofdm acquisition range */
+        ofdm->fmax = config->fmax;              /* frequency maximum for ofdm acquisition range */
 
     }
 
@@ -297,6 +301,9 @@ struct OFDM *ofdm_create(const struct OFDM_CONFIG *config) {
     ofdm->config.clip_en = ofdm->clip_en;
     memcpy(ofdm->config.tx_uw, ofdm->tx_uw, ofdm->nuwbits);
     ofdm->config.data_mode = ofdm->data_mode;
+    ofdm->config.fmin = ofdm->fmin;
+    ofdm->config.fmax = ofdm->fmax;
+    
 
     /* Calculate sizes from config param */
 
@@ -421,6 +428,10 @@ struct OFDM *ofdm_create(const struct OFDM_CONFIG *config) {
     ofdm->nin = ofdm->samplesperframe;
     ofdm->mean_amp = 0.0f;
     ofdm->foff_metric = 0.0f;
+    
+    ofdm->fmin = -50.0f;
+    ofdm->fmax = 50.0f;
+    
     /*
      * Unique Word symbol placement.  Note we need to group the UW
      * bits so they fit into symbols.  The LDPC decoder works on
@@ -543,10 +554,14 @@ static void allocate_tx_bpf(struct OFDM *ofdm) {
         quisk_filt_cfInit(ofdm->tx_bpf, filtP650S900, sizeof (filtP650S900) / sizeof (float));
         quisk_cfTune(ofdm->tx_bpf, ofdm->tx_centre / ofdm->fs);
     }
-    else if (!strcmp(ofdm->mode, "700E")) {
+    else if (!strcmp(ofdm->mode, "700E") || !strcmp(ofdm->mode, "2020")) {
         quisk_filt_cfInit(ofdm->tx_bpf, filtP900S1100, sizeof (filtP900S1100) / sizeof (float));
         quisk_cfTune(ofdm->tx_bpf, ofdm->tx_centre / ofdm->fs);
     }
+    else if (!strcmp(ofdm->mode, "2020B")) {
+        quisk_filt_cfInit(ofdm->tx_bpf, filtP1100S1300, sizeof (filtP1100S1300) / sizeof (float));
+        quisk_cfTune(ofdm->tx_bpf, ofdm->tx_centre / ofdm->fs);
+    }
     else if  (!strcmp(ofdm->mode, "datac0") || !strcmp(ofdm->mode, "datac3")) {
         quisk_filt_cfInit(ofdm->tx_bpf, filtP400S600, sizeof (filtP400S600) / sizeof (float));
         quisk_cfTune(ofdm->tx_bpf, ofdm->tx_centre / ofdm->fs);
@@ -758,7 +773,7 @@ static int est_timing(struct OFDM *ofdm, complex float *rx, int length,
 	    corr_st = corr_st + (rx[ind                        ] * wvec_pilot[j]);
             corr_en = corr_en + (rx[ind + ofdm->samplesperframe] * wvec_pilot[j]);
         }
-#endif
+#endif // __EMBEDDED__
         corr[i] = (cabsf(corr_st) + cabsf(corr_en)) * av_level;
     }
 
@@ -938,9 +953,10 @@ void ofdm_hilbert_clipper(struct OFDM *ofdm, complex float *tx, size_t n) {
         ofdm_clip(tx, OFDM_PEAK, n);
     }
 
-   /* BPF to remove out of band energy clipper introduces */
+    /* BPF to remove out of band energy clipper introduces */
     if (ofdm->tx_bpf_en) {
-        assert(!strcmp(ofdm->mode, "700D") || !strcmp(ofdm->mode, "700E") 
+        assert(!strcmp(ofdm->mode, "700D") || !strcmp(ofdm->mode, "700E")
+               || !strcmp(ofdm->mode, "2020") || !strcmp(ofdm->mode, "2020B")
                || !strcmp(ofdm->mode, "datac0") || !strcmp(ofdm->mode, "datac3"));
         assert(ofdm->tx_bpf != NULL);
         complex float tx_filt[n];
@@ -1158,9 +1174,9 @@ static void burst_acquisition_detector(struct OFDM *ofdm,
     
     float fmin, fmax, fstep;
     int tstep;
-    
+
     // initial search over coarse grid
-    tstep = 4; fstep = 5; fmin = -50.0; fmax = 50.0;
+    tstep = 4; fstep = 5; fmin = ofdm->fmin; fmax = ofdm->fmax;
     *timing_mx = est_timing_and_freq(ofdm, ct_est, foff_est,
                                  &rx[n], 2*ofdm->samplesperframe, 
                                  known_sequence, ofdm->samplesperframe,
@@ -1375,7 +1391,7 @@ static void ofdm_demod_core(struct OFDM *ofdm, int *rx_bits) {
     if (ofdm->timing_en == true) {
         /* update timing at start of every frame */
 
-        st = ofdm->rxbufst + ofdm->samplespersymbol + ofdm->samplesperframe - floorf(ofdm->ftwindowwidth / 2) + ofdm->timing_est;
+        st = ofdm->rxbufst + ofdm->samplespersymbol + ofdm->samplesperframe - (int) floorf((float)ofdm->ftwindowwidth / 2) + ofdm->timing_est;
         en = st + ofdm->samplesperframe - 1 + ofdm->samplespersymbol + ofdm->ftwindowwidth;
 
         complex float work[(en - st)];
@@ -1390,7 +1406,7 @@ static void ofdm_demod_core(struct OFDM *ofdm, int *rx_bits) {
 
         int ft_est = est_timing(ofdm, work, (en - st), 0.0f, &ofdm->timing_mx, &ofdm->timing_valid, 1);
 
-        ofdm->timing_est += ft_est - ceilf((float)ofdm->ftwindowwidth / 2) + 1;
+        ofdm->timing_est += ft_est - (int) ceilf((float)ofdm->ftwindowwidth / 2) + 1;
 
         if (ofdm->verbose > 2) {
             fprintf(stderr, "  ft_est: %2d timing_est: %2d sample_point: %2d\n", ft_est, ofdm->timing_est,
