@@ -59,10 +59,10 @@ void hs_pitch_refinement(MODEL *model, COMP Sw[], float pmin, float pmax,
 C2CONST c2const_create(int Fs, float framelength_s) {
     C2CONST c2const;
 
-    assert((Fs == 8000) || (Fs = 16000));
+    assert((Fs == 8000) || (Fs == 16000));
     c2const.Fs = Fs;
     c2const.n_samp = round(Fs*framelength_s);
-    c2const.max_amp = floor(Fs*P_MIN_S/2);
+    c2const.max_amp = floor(Fs*P_MAX_S/2);
     c2const.p_min = floor(Fs*P_MIN_S);
     c2const.p_max = floor(Fs*P_MAX_S);
     c2const.m_pitch = floor(Fs*M_PITCH_S);
@@ -372,11 +372,15 @@ void hs_pitch_refinement(MODEL *model, COMP Sw[], float pmin, float pmax, float
   for(p=pmin; p<=pmax; p+=pstep) {
     E = 0.0;
     Wo = TWO_PI/p;
+    
+    float bFloat = Wo * one_on_r;
+    float currentBFloat = bFloat;
 
     /* Sum harmonic magnitudes */
     for(m=1; m<=model->L; m++) {
-        b = (int)(m*Wo*one_on_r + 0.5);
+        b = (int)(currentBFloat + 0.5);
         E += Sw[b].real*Sw[b].real + Sw[b].imag*Sw[b].imag;
+        currentBFloat += bFloat;
     }
     /* Compare to see if this is a maximum */
 
